@@ -34,4 +34,6 @@ FEATURES = [
     "table",
     "chart",
     "markup",
+    "analytics",
+    "readability",
 ]
