@@ -39,7 +39,8 @@ class LivemarkRendererMixin(HTMLRenderer):
         return str(html)
 
     def render_fenced_code(self, element):
-        if element.lang == "table":
+        header = [element.lang] + element.extra.split()
+        if "table" in header:
             spec_yaml = str(element.children[0].children).strip()
             spec_python = yaml.safe_load(spec_yaml)
             spec_python["licenseKey"] = "non-commercial-and-evaluation"
@@ -57,7 +58,7 @@ class LivemarkRendererMixin(HTMLRenderer):
             table = {"spec": spec, "elem": f"livemark-table-{self.__tables}"}
             text = template.render(table=table)
             return text
-        if element.lang == "chart":
+        if "chart" in header:
             spec_yaml = str(element.children[0].children).strip()
             spec_python = yaml.safe_load(spec_yaml)
             spec = json.dumps(spec_python, ensure_ascii=False)
@@ -69,7 +70,7 @@ class LivemarkRendererMixin(HTMLRenderer):
             chart = {"spec": spec, "elem": f"livemark-chart-{self.__charts}"}
             text = template.render(chart=chart)
             return text
-        if element.lang == "script":
+        if "script" in header:
             code = str(element.children[0].children).strip()
             # TODO: raise on unsupported lang
             lang = "bash" if "bash" in element.extra else "python"
